#!/bin/bash

if [ $# == 0 ]; then
	echo usage $0 \<part_do_install\>
	echo \<part_to_install\> : all,numpy,gpaw,gpawsetup,ase
	exit 1
fi
my_part=$1

#==================================================================
#MODIFY the following lines:
#==================================================================
START=`pwd`
#DIRECTORIES:
GPAW_TMP=${HOME}/gpaw_tmp_latest
GPAW_PREFIX=${HOME}/gpaw_inst_latest
#VSC1:
#FFTW_LIB="/opt/intel/Compiler/11.1/046/mkl/lib/em64t/libfftw3xf_intel.a"
#CUSTOMIZE_FILE=$START/customize_vsc1_icc.py
#CONFIG_FILE=$START/config.py
#NUMPY_SITE_CFG=site.cfg.numpy.vsc1.txt
#SVN_LOCATION=/home/lv60000/markus/gpaw/svn
#
#VSC2:
FFTW_LIB="/opt/intel/mkl/lib/intel64/libfftw3xf_intel.a"
CUSTOMIZE_FILE=$START/customize_sl65_icc_mkl.py
NUMPY_SITE_CFG=site.cfg.numpy.sl65_icc_mkl.txt
CONFIG_FILE=$START/config.py
#SVN_LOCATION=/home/lv70474/tsusi/gpaw-svn/
SVN_LOCATION=/home/lv60000/markus/gpaw/svn
#
LDFLAGS="-lxc"
XC_PATH=/opt/sw/libxc/2.0.1
#set LIB XC PATH in customiz file
sed -i "s?.*lib_xc_path =.*?lib_xc_path = \"$XC_PATH\"?" $CUSTOMIZE_FILE
#
PYTHON='python -O'
#PYTHON='python'
#VERSION NUMBERS:
#GPAW_RELEASE=9616
#GPAW_RELEASE=10507
#vsc-2 working
#GPAW_RELEASE=11253
#ASE_RELEASE=3547
#latest apr 2014 working
GPAW_RELEASE=11364
ASE_RELEASE=3440

NUMPY=numpy-1.6.2
GPAW_SETUPS=gpaw-setups-0.9.9672
#URLs of needed libraries:
ASE_LOCATION="https://svn.fysik.dtu.dk/projects/ase/trunk ase"
GPAW_LOCATION="https://svn.fysik.dtu.dk/projects/gpaw/trunk gpaw"
GPAW_SETUPS_LOCATION=http://wiki.fysik.dtu.dk/gpaw-files/${GPAW_SETUPS}.tar.gz
NUMPY_LOCATION=http://garr.dl.sourceforge.net/project/numpy/NumPy/1.6.2/${NUMPY}.tar.gz
#==================================================================
#End of MODIFY
#==================================================================

#PREPARE:
PYTHON_VERSION=`python -V 2>&1| cut -d ' ' -f 2| cut -d '.' -f 1,2`
PYTHON_LIBS=$GPAW_PREFIX/lib64/python${PYTHON_VERSION}/site-packages
export PYTHONPATH=$PYTHON_LIBS:$PYTHONPATH
export PATH=$PYTHON_LIBS/ase/tools:$PATH
export PYTHONOPTIMIZE="1"
mkdir -p $GPAW_PREFIX/lib64
mkdir -p $GPAW_TMP
mkdir -p $SVN_LOCATION
if [ $my_part == 'all' ]; then
	ln -s $GPAW_PREFIX/lib64 $GPAW_PREFIX/lib
	rm log_*
	mkdir -p $GPAW_TMP
fi


#NUMPY
if [ $my_part == 'all' -o $my_part == 'numpy' ]; then
	cd $GPAW_TMP
	wget $NUMPY_LOCATION
	rm -rf ${NUMPY}
	tar zxf ${NUMPY}.tar.gz
	cd ${NUMPY}
	#for optimizing:
	mv site.cfg site.cfg.orig
	ln -s ${START}/${NUMPY_SITE_CFG} site.cfg
	sed -i "s?self.cc_exe = 'icc -fPIC'?self.cc_exe = 'icc -O3 -g -fPIC -fp-model strict -fomit-frame-pointer -openmp -xhost'?"  numpy/distutils/intelccompiler.py
	sed -i "s?'compiler_f90' : \[None\],?'compiler_f90' : \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
	sed -i "s?'compiler_f77' : \[None, \"-FI\", \"-w90\", \"-w95\"\],?'compiler_f77' :  \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
	sed -i "s?'compiler_fix' : \[None, \"-FI\"\],?'compiler_fix' :  \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
	${PYTHON} setup.py config --compiler=intel build_clib --compiler=intel build_ext --compiler=intel install --prefix=$GPAW_PREFIX &> $START/log_numpy
	#
	#standard installations
	#BLAS=None LAPACK=None ATLAS=None ${PYTHON} setup.py install --prefix=$GPAW_PREFIX &> $START/log_numpy
	#${PYTHON} setup.py install --prefix=$GPAW_PREFIX &> $START/log_numpy
fi

#ASE
if [ $my_part == 'all' -o $my_part == 'ase' ]; then
	cd $SVN_LOCATION 
	svn checkout ${ASE_LOCATION} -r $ASE_RELEASE
	cd $GPAW_TMP
	rm -rf ${ASE_RELEASE}
	cp -r $SVN_LOCATION/ase ${ASE_RELEASE}
	cd $ASE_RELEASE
	$PYTHON setup.py install --prefix=$GPAW_PREFIX  &> $START/log_ase
fi
#GPAW_SETUPS:
if [ $my_part == 'all' -o $my_part == 'gpawsetups' ]; then
	cd $GPAW_TMP
	wget $GPAW_SETUPS_LOCATION
	tar zxf ${GPAW_SETUPS}.tar.gz
	mv ${GPAW_SETUPS} ${GPAW_PREFIX}
fi

if [ "$my_part" == 'all' -o "$my_part" == "gpaw" ]; then
	cd $SVN_LOCATION
	svn -r $GPAW_RELEASE checkout ${GPAW_LOCATION} 
	cd $GPAW_TMP
	
	cp -r $SVN_LOCATION/gpaw $GPAW_RELEASE
        cd $GPAW_RELEASE
        mv customize.py customize.py.orig
        ln -s $CUSTOMIZE_FILE customize.py
        mv config.py config.py.orig
        ln -s $CONFIG_FILE config.py
        sed -i "s?libfftw3.so?${FFTW_LIB}?" gpaw/fftw.py
        ${PYTHON} setup.py install --prefix=$GPAW_PREFIX  &> $START/log_gpaw
fi

echo ===================================================================================
echo add these paths to your .bashrc
echo
echo export LD_LIBRARY_PATH=/opt/sw/libxc/2.0.1/lib:\$LD_LIBRARY_PATH
echo export GPAW_SETUP_PATH=$GPAW_PREFIX/$GPAW_SETUPS
echo export PYTHONPATH=$PYTHON_LIBS:\$PYTHONPATH
echo export PATH=$PYTHON_LIBS/ase/tools:$GPAW_PREFIX/bin:\$PATH
echo ===================================================================================
